@@ -61,14 +61,9 @@ class FilegroupLoad(FilegroupScan):
         commands = self.get_commands(keyring, memory)
         for cmd in commands:
             log.debug('Command: %s', str(cmd).replace('\n', '\n\t'))
-            file = self.open_file(cmd.filename, mode='r', log_lvl='info')
-            try:
+
+            with self.open_file(cmd.filename, mode='r', log_lvl='info') as file:
                 self.load_cmd(file, cmd)
-            except Exception:
-                self.close_file(file)
-                raise
-            else:
-                self.close_file(file)
 
         self.do_post_loading(keyring)
 
@@ -359,8 +354,7 @@ class FilegroupLoad(FilegroupScan):
         cmds = self.get_commands(infile, memory)
 
         for cmd in cmds:
-            file = self.open_file(cmd.filename, 'r', 'debug')
-            try:
+            with self.open_file(cmd.filename, 'r', 'debug') as file:
                 log.debug('Scanning %s for variables specific attributes.', cmd.filename)
 
                 for k in cmd:
@@ -369,12 +363,6 @@ class FilegroupLoad(FilegroupScan):
                 memory = [v for k in cmd for v in k.memory['var']]
                 scan_attr(self, file, infile, memory)
 
-            except Exception:
-                self.close_file(file)
-                raise
-            else:
-                self.close_file(file)
-
     def _get_infile_name(self, var: str) -> str:
         """Get infile name."""
         cs = self.cs['var']
@@ -382,7 +370,7 @@ class FilegroupLoad(FilegroupScan):
             return cs.in_idx[cs.get_str_index(var)]
         return var
 
-    def write(self, filename: str, wd: str = None,
+    def write(self, filename: str, directory: str = None,
               file_kw: Dict = None, var_kw: Dict[str, Dict] = None,
               keyring: Keyring = None, **keys: KeyLike):
         """Write data to disk.
@@ -404,16 +392,16 @@ class FilegroupLoad(FilegroupScan):
         All attributes from the VariablesInfo are put in the file if their
         name do not start with an '_'.
 
-        :param wd: Directory to place the file. If None, the filegroup root is
-            used instead.
+        :param directory: Directory to place the file. If None, the filegroup
+            root is used instead.
         :param file_kw: Keywords argument to pass to `open_file`.
         :param var_kw: Variables specific arguments. Keys are variables names,
             values are dictionnary containing options. Use '_all' to add an
             option for all variables.
         """
-        if wd is None:
-            wd = self.root
-        filename = os.path.join(wd, filename)
+        if directory is None:
+            directory = self.root
+        filename = os.path.join(directory, filename)
 
         krg_mem = Keyring.get_default(keyring=keyring, **keys)
         krg_mem.set_default('var', slice(None))
@@ -453,14 +441,8 @@ class FilegroupLoad(FilegroupScan):
         file_kw.setdefault('mode', 'w')
         file_kw.setdefault('log_lvl', 'INFO')
 
-        file = self.open_file(filename, **file_kw)
-        try:
+        with self.open_file(filename, **file_kw) as file:
             self._write(file, cmd, var_kw)
-        except Exception:
-            self.close_file(file)
-            raise
-        else:
-            self.close_file(file)
 
     def _write(self, file: File, cmd: Command, var_kw: Dict[str, Any]):
         """Write data in file.
@@ -499,14 +481,8 @@ class FilegroupLoad(FilegroupScan):
                 cks.infile.limit(cks.memory)
             log.debug('Command: %s', cmd)
 
-            file = self.open_file(cmd.filename, mode='r+', log_lvl='info')
-            try:
+            with self.open_file(cmd.filename, mode='r+', log_lvl='info') as file:
                 self.add_variables_to_file(file, cmd[0], **{var: kwargs})
-            except Exception:
-                self.close_file(file)
-                raise
-            else:
-                self.close_file(file)
 
         return True
 
